@@ -1,10 +1,13 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 import re
-import bson
-import pymongo
+try:
+    import bson
+    import pymongo
+except ImportError:
+    pass
 
-__version__ = '0.0.2'
+__version__ = '0.0.3'
 
 
 class cached_classmethod(object):
